@@ -13,6 +13,8 @@
 #'  in NetCDFv3 format (numeric). Default output is NetCDFv4.
 #'@param overwrite logical; should existing output file be overwritten?
 #'@param verbose logical; if TRUE, progress messages are shown
+#'@param nc Alternatively to \code{infile} you can specify the input as an
+#'  object of class `ncdf4` (as returned from \code{ncdf4::nc_open}).
 #'
 #'@return A NetCDF file including a time series of monthly standard deviation is written.
 #'@export
@@ -56,6 +58,6 @@
 #'
 #'unlink(c(file.path(tempdir(),"CMSAF_example_file.nc"), 
 #'  file.path(tempdir(),"CMSAF_example_file_monsd.nc")))
-monsd <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE) {
-  monx_wrapper(5, var, infile, outfile, nc34, overwrite, verbose)
+monsd <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE, nc = NULL) {
+  monx_wrapper(5, var, infile, outfile, nc34, overwrite, verbose, nc = nc)
 }
